Struct Column

pub struct Column<T: WidgetList> {
    pub children: T,
    pub space_between: f64,
    pub main_axis_size: MainAxisSize,
    pub main_axis_alignment: MainAxisAlignment,
    pub cross_axis_size: CrossAxisSize,
    pub cross_axis_alignment: CrossAxisAlignment,
}

Fields

children: Tspace_between: f64main_axis_size: MainAxisSizemain_axis_alignment: MainAxisAlignmentcross_axis_size: CrossAxisSizecross_axis_alignment: CrossAxisAlignment

Implementations

Source

impl Column<()>

pub fn builder() -> Self

Source

impl<WidgetList_: WidgetList> Column<WidgetList_>

pub fn children(self, children: impl WidgetList) -> Column<impl WidgetList>

List of children widgets to be laid out by the Column.

Note

See WidgetList for all the types that you can use as children.

pub fn main_axis_size(self, size: MainAxisSize) -> Self

Whether Column should take full available height or only the minimum to fit children.

Note

The default is MainAxisSize::Min.

If one of your children is flexible, MainAxisSize of this Column will be the same as if it was set to MainAxisSize::Max.

pub fn main_axis_alignment(self, alignment: MainAxisAlignment) -> Self

Specifies how Column should layout its children on the vertical axis.

Note

The default is MainAxisAlignment::Start.

pub fn cross_axis_size(self, size: CrossAxisSize) -> Self

Whether Column should take full available width or only the minimum to fit children.

Note

The default is CrossAxisSize::Min.

pub fn cross_axis_alignment(self, alignment: CrossAxisAlignment) -> Self

Specifies how Column should layout its children on the horizontal axis.

Note

The default is MainAxisAlignment::Start.

pub fn space_between(self, amount: f64) -> Self

Minimum amount of empty space added between children widgets.

Note

The default is 0.