pub struct KeyboardEventDetector<W: Widget, F: Fn(KeyEvent)> {
pub on_event: F,
pub child: W,
}Fields
on_event: Fchild: WTrait Implementations
Sourceimpl<W: Widget, F: Fn(KeyEvent)> ViewWidget for KeyboardEventDetector<W, F>
impl<W: Widget, F: Fn(KeyEvent)> ViewWidget for KeyboardEventDetector<W, F>
fn build<'w>(&'w self, _: BuildContext<'w, Self>) -> Self::Widget<'w>
Sourceimpl<W: Widget, F: Fn(KeyEvent)> Widget for KeyboardEventDetector<W, F>
impl<W: Widget, F: Fn(KeyEvent)> Widget for KeyboardEventDetector<W, F>
Sourcefn unique_type(&self) -> TypeId
fn unique_type(&self) -> TypeId
Implementation should return the same unique TypeId for given structure definition,
even if that structure contains generic parameters. This is used to preserve state
between generic widgets.
fn kind<'frui>(&'frui self) -> WidgetKind<'_>
Sourceimpl<W: Widget, F: Fn(KeyEvent)> WidgetDerive for KeyboardEventDetector<W, F>
impl<W: Widget, F: Fn(KeyEvent)> WidgetDerive for KeyboardEventDetector<W, F>
Sourceimpl<W: Widget, F: Fn(KeyEvent)> WidgetState for KeyboardEventDetector<W, F>
impl<W: Widget, F: Fn(KeyEvent)> WidgetState for KeyboardEventDetector<W, F>
type State = Option<CallbackKey>
fn create_state<'a>(&'a self) -> Self::State
Sourcefn mount(&self, ctx: BuildContext<'_, Self>)
fn mount(&self, ctx: BuildContext<'_, Self>)
Called when the widget is mounted into the tree (before build). Read more
Sourcefn unmount(&self, ctx: BuildContext<'_, Self>)
fn unmount(&self, ctx: BuildContext<'_, Self>)
Called when the widget is unmounted from the tree. At this point given
widget may be dropped or mounted again with its configuration updated. Read more